==> ocstore25_7_4.zip: OcStore/Spiky/ScriptLuaFunc.h <==
#pragma once
#include "global.h"
lua_State* NewScriptL(void* pCmdOpFunc);
int Tsc_TRA(lua_State* L);//ҵĳͼ
int Tsc_DBG(lua_State* L);//
int Tsc_WAI(lua_State* L);//ȴ
int Tsc_WAS(lua_State* L);//ͣ¼ֱվڵ
int Tsc_STY(lua_State* L);//ıʽ
int Tsc_MSG(lua_State* L);//ʾı
int Tsc_MS2(lua_State* L);//Ϸı
int Tsc_MS3(lua_State* L);//Ϸı
int Tsc_MS4(lua_State* L);//Զı
int Tsc_MSS(lua_State* L);//ıʾٶ
int Tsc_TUR(lua_State* L);//ıʾ
int Tsc_NOD(lua_State* L);//z
int Tsc_CAT(lua_State* L);//ı
int Tsc_CLR(lua_State* L);//ı
int Tsc_CLO(lua_State* L);//ղرı
int Tsc_FCL(lua_State* L);//ıɫ
int Tsc_FNT(lua_State* L);//
int Tsc_FSZ(lua_State* L);//ֺ
int Tsc_FAC(lua_State* L);//
int Tsc_CMU(lua_State* L);//org
int Tsc_PMU(lua_State* L);//ͣorg
int Tsc_RMU(lua_State* L);//ָorg
int Tsc_SOU(lua_State* L);//wav
int Tsc_CMU2(lua_State* L);//ogg
int Tsc_PMU2(lua_State* L);//ͣogg
int Tsc_RMU2(lua_State* L);//ָogg
int Tsc_PRI(lua_State* L);//¼ǰסϷ
int Tsc_KEY(lua_State* L);//¼ǰס
int Tsc_MM0(lua_State* L);//ҵˮƽٶΪ0
int Tsc_MV0(lua_State* L);//ٶ0
int Tsc_MOV(lua_State* L);//Ƶ
int Tsc_SLR(lua_State* L);//ҵ泯
int Tsc_GLR(lua_State* L);//ȡҵ泯
int Tsc_MYB(lua_State* L);//Һ
int Tsc_FON(lua_State* L);//۽Npc
int Tsc_FOM(lua_State* L);//۽
int Tsc_MNA(lua_State* L);//ʾͼ
int Tsc_FAI(lua_State* L);//
int Tsc_FAO(lua_State* L);//
int Tsc_HMC(lua_State* L);//
int Tsc_SMC(lua_State* L);//ʾ
int Tsc_ANP(lua_State* L);//Npc
int Tsc_AMC(lua_State* L);//Ҷ
int Tsc_ATP(lua_State* L);//ĳһNpc
int Tsc_TMC(lua_State* L);//Ҷ
int Tsc_TNP(lua_State* L);//Npc
int Tsc_CNP(lua_State* L);//滻NPC
int Tsc_MNP(lua_State* L);//ƶNPC
int Tsc_BSL(lua_State* L);//Bossս(ʾbossѪ)
int Tsc_SAV(lua_State* L);//Ϸ
int Tsc_LAY(lua_State* L);//ͼǷɼ
int Tsc_FLP(lua_State* L);//flag
int Tsc_FLS(lua_State* L);//Ƴflag
int Tsc_FLJ(lua_State* L);//flagǷ
int Tsc_YNJ(lua_State* L);//YesNoѡ
int Tsc_YES(lua_State* L);//һYNJѡ
int Tsc_INI(lua_State* L);//Ϸ
int Tsc_ESC(lua_State* L);//ر⻭
int Tsc_W99(lua_State* L);//¼ʱıʾ
int Tsc_MAP(lua_State* L);//ʾϷͼ
int Tsc_PLY(lua_State* L);//ȡһε¼±
int Tsc_SNP(lua_State* L);//NPC
int Tsc_DNP(lua_State* L);//ɾNPC
int Tsc_MLP(lua_State* L);//ֵ
int Tsc_ECJ(lua_State* L);//ⷿǷĳ¼ʵ
int Tsc_LIP(lua_State* L);//ָ
int Tsc_TGR(lua_State* L);//ȡ¼Ĵ
int Tsc_ELT(lua_State* L);//ʵԤ
int Tsc_SPL(lua_State* L);//ҿƵȫʵ
int Tsc_SGP(lua_State* L);//ȫNPC
int Tsc_CGP(lua_State* L);//Ʋһȫֵλ
int Tsc_DGP(lua_State* L);//ɾȫNPC
int Tsc_AGP(lua_State* L);//AIȫNPC
int Tsc_P2A(lua_State* L);//2AIлúͽֹ
int Tsc_WET(lua_State* L);//Ƿˮ
int Tsc_EID(lua_State* L);//صĿʵid
int Tsc_RGI(lua_State* L);//עƷ
int Tsc_ITP(lua_State* L);//ƷظƷ
int Tsc_ITS(lua_State* L);//ƳƷ-1ΪƳȫ,ʣ
int Tsc_ITJ(lua_State* L);//ǷӵĳƷ
int Tsc_ITC(lua_State* L);//ӵĳƷ
int Tsc_RGM(lua_State* L);//ע
int Tsc_MSA(lua_State* L);//񣬷ID
int Tsc_MSD(lua_State* L);//ɾ
int Tsc_MSR(lua_State* L);//滻
int Tsc_MSJ(lua_State* L);//Ƿӵĳ
int Tsc_SUB(lua_State* L);//лϷcmd
int Tsc_LOC(lua_State* L);//ǰƷǷ
int Tsc_GIT(lua_State* L);//չʾĳƷ
int Tsc_IMM(lua_State* L);//ݵUI
int Tsc_SKP(lua_State* L);//ÿ
int Tsc_SKS(lua_State* L);//Ƴ
int Tsc_SKJ(lua_State* L);//Ƿ
int Tsc_POS(lua_State* L);//
int Tsc_CMP(lua_State* L);//µͼϵƬ
int Tsc_QUA(lua_State* L);//ζĻ
int Tsc_SWC(lua_State* L);//滻µҽɫ
int Tsc_SWP(lua_State* L);//12Ľɫ
int Tsc_MCN(lua_State* L);//ȡҵĽɫ
int Tsc_MCI(lua_State* L);//ȡҵ±
int Tsc_GOP(lua_State* L);//ȡǰϷģʽ
int Tsc_FLA(lua_State* L);//
int Tsc_KIL(lua_State* L);//ɱĳһ͵ĵˣػɱ
int Tsc_STA(lua_State* L);//שƻЧ
int Tsc_ZAM(lua_State* L);//MP
int Tsc_RST(lua_State* L);//λùؿе
int Tsc_CRE(lua_State* L);//ʼβ´
int Tsc_KEN(lua_State* L);//ȡҰı
int Tsc_DIF(lua_State* L);//ȡǰϷѶ

==> ocstore25_8_11.zip: OcStore/Spiky/ScriptLuaFunc.h <==
#pragma once
#include "global.h"
lua_State* NewScriptL(void* pCmdOpFunc);
int Tsc_TRA(lua_State* L);//ҵĳͼ
int Tsc_DBG(lua_State* L);//
int Tsc_WAI(lua_State* L);//ȴ
int Tsc_WAS(lua_State* L);//ͣ¼ֱվڵ
int Tsc_STY(lua_State* L);//ıʽ
int Tsc_MSG(lua_State* L);//ʾı
int Tsc_MS2(lua_State* L);//Ϸı
int Tsc_MS3(lua_State* L);//Ϸı
int Tsc_MS4(lua_State* L);//Զı
int Tsc_MSS(lua_State* L);//ıʾٶ
int Tsc_TUR(lua_State* L);//ıʾ
int Tsc_NOD(lua_State* L);//z
int Tsc_CAT(lua_State* L);//ı
int Tsc_CLR(lua_State* L);//ı
int Tsc_CLO(lua_State* L);//ղرı
int Tsc_FCL(lua_State* L);//ıɫ
int Tsc_FNT(lua_State* L);//
int Tsc_FSZ(lua_State* L);//ֺ
int Tsc_FAC(lua_State* L);//
int Tsc_CMU(lua_State* L);//org
int Tsc_PMU(lua_State* L);//ͣorg
int Tsc_RMU(lua_State* L);//ָorg
int Tsc_SOU(lua_State* L);//wav
int Tsc_CMU2(lua_State* L);//ogg
int Tsc_PMU2(lua_State* L);//ͣogg
int Tsc_RMU2(lua_State* L);//ָogg
int Tsc_PRI(lua_State* L);//¼ǰסϷ
int Tsc_KEY(lua_State* L);//¼ǰס
int Tsc_MM0(lua_State* L);//ҵˮƽٶΪ0
int Tsc_MV0(lua_State* L);//ٶ0
int Tsc_MOV(lua_State* L);//Ƶ
int Tsc_SLR(lua_State* L);//ҵ泯
int Tsc_GLR(lua_State* L);//ȡҵ泯
int Tsc_MYB(lua_State* L);//Һ
int Tsc_FON(lua_State* L);//۽Npc
int Tsc_FOM(lua_State* L);//۽
int Tsc_MNA(lua_State* L);//ʾͼ
int Tsc_FAI(lua_State* L);//
int Tsc_FAO(lua_State* L);//
int Tsc_HMC(lua_State* L);//
int Tsc_SMC(lua_State* L);//ʾ
int Tsc_ANP(lua_State* L);//Npc
int Tsc_AMC(lua_State* L);//Ҷ
int Tsc_ATP(lua_State* L);//ĳһNpc
int Tsc_TMC(lua_State* L);//Ҷ
int Tsc_TNP(lua_State* L);//Npc
int Tsc_CNP(lua_State* L);//滻NPC
int Tsc_MNP(lua_State* L);//ƶNPC
int Tsc_BSL(lua_State* L);//Bossս(ʾbossѪ)
int Tsc_SAV(lua_State* L);//Ϸ
int Tsc_LAY(lua_State* L);//ͼǷɼ
int Tsc_FLP(lua_State* L);//flag
int Tsc_FLS(lua_State* L);//Ƴflag
int Tsc_FLJ(lua_State* L);//flagǷ
int Tsc_YNJ(lua_State* L);//YesNoѡ
int Tsc_YES(lua_State* L);//һYNJѡ
int Tsc_INI(lua_State* L);//Ϸ
int Tsc_ESC(lua_State* L);//ر⻭
int Tsc_W99(lua_State* L);//¼ʱıʾ
int Tsc_MAP(lua_State* L);//ʾϷͼ
int Tsc_PLY(lua_State* L);//ȡһε¼±
int Tsc_SNP(lua_State* L);//NPC
int Tsc_DNP(lua_State* L);//ɾNPC
int Tsc_MLP(lua_State* L);//ֵ
int Tsc_ECJ(lua_State* L);//ⷿǷĳ¼ʵ
int Tsc_LIP(lua_State* L);//ָ
int Tsc_MIP(lua_State* L);//ָ
int Tsc_TGR(lua_State* L);//ȡ¼Ĵ
int Tsc_ELT(lua_State* L);//ʵԤ
int Tsc_SPL(lua_State* L);//ҿƵȫʵ
int Tsc_SGP(lua_State* L);//ȫNPC
int Tsc_CGP(lua_State* L);//Ʋһȫֵλ
int Tsc_DGP(lua_State* L);//ɾȫNPC
int Tsc_AGP(lua_State* L);//AIȫNPC
int Tsc_P2A(lua_State* L);//2AIлúͽֹ
int Tsc_WET(lua_State* L);//Ƿˮ
int Tsc_EID(lua_State* L);//صĿʵid
int Tsc_RGI(lua_State* L);//עƷ
int Tsc_ITP(lua_State* L);//ƷظƷ
int Tsc_ITS(lua_State* L);//ƳƷ-1ΪƳȫ,ʣ
int Tsc_ITJ(lua_State* L);//ǷӵĳƷ
int Tsc_ITC(lua_State* L);//ӵĳƷ
int Tsc_RGM(lua_State* L);//ע
int Tsc_MSA(lua_State* L);//񣬷ID
int Tsc_MSD(lua_State* L);//ɾ
int Tsc_MSR(lua_State* L);//滻
int Tsc_MSJ(lua_State* L);//Ƿӵĳ
int Tsc_SUB(lua_State* L);//лϷcmd
int Tsc_LOC(lua_State* L);//ǰƷǷ
int Tsc_GIT(lua_State* L);//չʾĳƷ
int Tsc_IMM(lua_State* L);//ݵUI
int Tsc_SKP(lua_State* L);//ÿ
int Tsc_SKS(lua_State* L);//Ƴ
int Tsc_SKJ(lua_State* L);//Ƿ
int Tsc_POS(lua_State* L);//
int Tsc_CMP(lua_State* L);//µͼϵƬ
int Tsc_QUA(lua_State* L);//ζĻ
int Tsc_SWC(lua_State* L);//滻µҽɫ
int Tsc_SWP(lua_State* L);//12Ľɫ
int Tsc_MCN(lua_State* L);//ȡҵĽɫ
int Tsc_MCI(lua_State* L);//ȡҵ±
int Tsc_GOP(lua_State* L);//ȡǰϷģʽ
int Tsc_FLA(lua_State* L);//
int Tsc_KIL(lua_State* L);//ɱĳһ͵ĵˣػɱ
int Tsc_STA(lua_State* L);//שƻЧ
int Tsc_ZAM(lua_State* L);//MP
int Tsc_RST(lua_State* L);//λùؿе
int Tsc_CRE(lua_State* L);//ʼβ´
int Tsc_KEN(lua_State* L);//ȡҰı
int Tsc_DIF(lua_State* L);//ȡǰϷѶ
int Tsc_TIM(lua_State* L);//ʾʼʱ
int Tsc_STC(lua_State* L);//ʱ
int Tsc_LTC(lua_State* L);//ȡʱ
